@@ -72,5 +72,4 @@ class RabbitMqEventBus(IEventBus):
         channel.close()
 
     def close(self):
-        if self.connector.get_connection(self.rabbitmq_key).is_open:
-            self.connector.get_connection(self.rabbitmq_key).close()
+        self.connector.close(self.rabbitmq_key)
